/*
 * ItemWithDiscountCallbackRequest
 *
 * 03/12/2005
 *
 * This class is used to format the prompt message for the 
 * EXTENSION_ITEM_WITH_COUPON_PROMPT callback.  The discount
 * amount value is in the <DiscountValue> element within the
 * <AdditionalData> element.  This value can be placed into the 
 * text prompt
 * 
 * The text for the callback is something like:
 * 
 *   Get up to {0} off with a coupon.  Do you have a coupon?
 *   
 * This class formats the message with the additional and puts
 * it back into the SC_CALLBACK_PROMPT variable, which is 
 * displayed on the the screen.
 */
package com.ibm.sureview.customer.sc.application;

import java.text.MessageFormat;

import com.ibm.sureview.application.SureviewApplication;
import com.ibm.sureview.application.UserData;
import com.ibm.sureview.sc.application.SCCallbackRequest;
import com.ibm.sureview.sc.application.SCData;
import com.ibm.sureview.sc.application.SCSureviewApplication;
import com.ibm.sureview.sc.application.SCXMLNode;
import com.ibm.sureview.sc.application.XPathKeys;
import com.ibm.sureview.sc.util.SCUtil;

/**
 * ItemWithDiscountCallbackRequest is a class that manages all data for a callback request.
 */
public class ItemWithCouponCallbackRequest extends SCCallbackRequest
{
    /**
     * Constructor
     */
    public ItemWithCouponCallbackRequest(SCXMLNode requestNode)
    {
       super(requestNode);
    }

   /**
    * Called when this callback request is "active". For pending action 
    * callbacks, this is when the action  representing the callback is 
    * selected from the pending action list (the top one in the list).  
    * This method should perform any housekeeping duties as necessary 
    * (such as setting SCData property values).
    */
   public void activate()
   {
      super.activate();
      String textValue = "";
      String orderDiscount = "";

      //get the XML node containing <CallbackHeaderExtension>
      SCXMLNode node = SCUtil.getNode(getNode(), XPathKeys.CALLBACK_HEADER_EXTENSION);
      
      if (node != null)
      {
         //get the XML node containing <KeyValuePair>.  Normally you would call node.getChildren()
         //to get all key-value pairs, then loop through them.  But this only has one <KeyValuePair> 
         node = SCUtil.getNode(node, XPathKeys.CALLBACK_KEY_VALUE_PAIR);
         
         //get the key-value pairs
         String key   = SCUtil.getDataValue(node, XPathKeys.CALLBACK_KEY);
         String value = SCUtil.getDataValue(node, XPathKeys.CALLBACK_VALUE);

         if ((key != null) && (key.equals("DISCOUNT_VALUE")))
         {
            if (value != null)
            {
               orderDiscount = value;

               //Set value in simple UserData variable for Exercise 6
               UserData userData = ((SCSureviewApplication)SureviewApplication.getInstance()).getUserData();
               userData.put(CustomerUserData.CUSTOMER_COUPON_DISCOUNT, value);
            }
         }
      }

      //Get the current CALLBACK_PROMPT
      SCData scData = ((SCSureviewApplication)SureviewApplication.getInstance()).getSCData();
      textValue = (String)scData.get(SCData.CALLBACK_PROMPT);

      //for safety, set a default value if nothing was found
      if(textValue == null)
      {
         textValue = "Get up to {0} off with a coupon.  Do you have a coupon?";
      }

      //format the message with the discount value
      Object[] parmArgs = {orderDiscount};
      textValue = MessageFormat.format(textValue, parmArgs);
      
      //Put the message back in the Callback Prompt for Exercise 5
      scData.put(SCData.CALLBACK_PROMPT, textValue);
   }
}
