@REM -------------------------------------------------------------------
@REM This file generates the two buisness partner jars for the SI GUI.
@REM ANT will be used to create the jar files.  If ANT is not installed,
@REM then the jar.exe is used to create the files.
@REM
@REM The resulting files are 
@REM
@REM  svscbusp.jar     - Main jar, contains class, xml, and property files
@REM  svscbusprsc.jar  - Resource jar, contains images.
@REM -------------------------------------------------------------------
@setlocal
@set BUILD_DIR=build
@set HOME_DIR=..


@cd %BUILD_DIR%
@echo. 

@if "%ANT_HOME%"=="" goto ant_error
@REM -------------------------------------------------------------------
@REM Build the Jars using ANT and the build.xml file
@REM -------------------------------------------------------------------
@%ANT_HOME%\bin\ant %1
@cd %HOME_DIR%
goto end

:ant_error
@echo -----------------------------------------------------------------
@echo Could not locate ANT so build.xml will not be used.  
@echo Using javac.exe and jar.exe directly to compile and jar the files
@echo -----------------------------------------------------------------

@REM -------------------------------------------------------------------
@REM Set environment variables
@REM -------------------------------------------------------------------
@REM set the path to the jar and javac commands
@set JAR_COMMAND="%JAVA_HOME%"\bin\jar
@set JAVAC_COMMAND="%JAVA_HOME%"\bin\javac

@REM Set your business partner jar names
@set BUSP_JAR=svscbusp.jar
@set BUSPRSC_JAR=svscbusprsc.jar

@REM Set the classpath for compilation
@set CLASSES=.\com\ibm\sureview\customer\sc
@set CLASS_PATH="%GUI_HOME%"\sc\svsc.jar;"%GUI_HOME%"\sureview.jar;"%AEF_HOME%"\aef.jar;

@REM -------------------------------------------------------------------
@REM Can't use build.xml so compile and jar directly
@REM -------------------------------------------------------------------
@echo.
@echo Compiling classes...
@%JAVAC_COMMAND% -classpath %CLASS_PATH% %CLASSES%\application\*.java %CLASSES%\factory\*.java %CLASSES%\guiComponent\*.java %CLASSES%\util\*.java

@REM -------------------------------------------------------------------
@REM Build the Jars using the jar.exe applicaton.  Note that this does not
@REM compile any classes.  Use ANT instead
@REM -------------------------------------------------------------------
@echo.
@echo Jaring all files...
@%JAR_COMMAND% -cfM %HOME_DIR%\%BUSP_JAR% *.pro *.properties *.xml *.txt %CLASSES%\application\*.class %CLASSES%\factory\*.class %CLASSES%\guiComponent\*.class %CLASSES%\util\*.class
@%JAR_COMMAND% -cfM %HOME_DIR%\%BUSPRSC_JAR% .\images\*.gif .\images\*.jpg
@cd %HOME_DIR%
@REM -------------------------------------------------------------------
@REM Copy the Jars to the user\sc directory
@REM -------------------------------------------------------------------
@echo.
@echo Copying jars to ...
@copy %BUSP_JAR% "%SI_HOME%\user\sc"
@copy %BUSPRSC_JAR% "%SI_HOME%\user\sc"
@goto end

:error
@echo. 
@echo. 
@echo   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
@echo   ERROR: Could not run %error_name%.exe!
@echo          Make sure %error_name% is installed and the %error_name%_HOME
@echo          environment variable is set correctly.
@echo   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
@REM  cause a beep  (hex 7)
@echo 

:end
@endlocal

